# Installation

## Stable release

To install `pyproject2conda`, run this command in your terminal:

```bash
pip install pyproject2conda
```

or

```bash
conda install -c wpk-nist pyproject2conda
```

This is the preferred method to install pyproject2conda, as it will always
install the most recent stable release.

## From sources

See [](./contributing) for details on installing from source.
